@@ -53,7 +53,7 @@ DummyDecorationBridge::DummyDecorationBridge(const QString &decorationTheme, QOb
         m_decoration = m_factory->create<KDecoration2::Decoration>(m_factory, QVariantList({args}));
     }
 
-    auto decorationSettings = QSharedPointer<KDecoration2::DecorationSettings>::create(this);
+    auto decorationSettings = std::make_shared<KDecoration2::DecorationSettings>(this);
     m_decoration->setSettings(decorationSettings);
     m_decoration->init();
 
@@ -94,17 +94,6 @@ void DummyDecorationBridge::paintButton(QPainter &painter, const QString &button
                                                               QVariant::fromValue(m_decoration),
                                                           }))};
 
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 87)
-    if (button == nullptr) {
-        button.reset(m_factory->create<KDecoration2::DecorationButton>(QStringLiteral("button"),
-                                                                       m_decoration,
-                                                                       QVariantList({
-                                                                           QVariant::fromValue(strToButtonType(buttonType)),
-                                                                           QVariant::fromValue(m_decoration),
-                                                                       })));
-    }
-#endif
-
     if (button == nullptr) {
         return;
     }
@@ -224,3 +213,5 @@ KDecoration2::DecorationButtonType DummyDecorationBridge::strToButtonType(const
 }
 
 }
+
+#include "moc_dummydecorationbridge.cpp"
